const assert = require('chai').assert;
const expect = require('chai').expect;
const uuid = require('uuid');
const index = require('../index');

const info = {
    merno: '777290058147253',
    cert_sn: '40220995861346480087409489142384722381',
    sign_pem: `-----BEGIN RSA PRIVATE KEY-----
MIICXAIBAAKBgQCQvyFGMGkKxojiX2VUkXvu6mNJk/ayHRHXo7KOxC3oQE+QZPk2
4MnBT5eqn7pmxxkZ2Ky5NKCN914LEPJ+6+XatDEIxU7ZXDHQuGa6/Q5W35lh9aC+
M7ULZ8eWjIKM+zlnS5MrUOML8EpvoETCnC2V3YfgM45tTIXEEo3Dkx5RWwIDAQAB
AoGAP9F1OzwW5CBas+w5ggrO6KzA7+zj5O36MuhCzr1iPDc2nURXuMFtUuTjyt+3
0J7Ry1qD9PhmHZHGDfz/3cPmSFgxOmEkvc/xN0TGNfN+WZdcc/n16DKvOUXfEUE1
nx0g6UPP3MI86TaIX+cmHFuSIfRgcFOj1+9xsx8DtYkVVZkCQQDICwzlq3eDw7N+
zkBCie/UhvGOTxjPpZHyjaR3z9CWBETyzw3WM3pgBxFafYXo2ad7HUjYm7bCIM9b
DB6DufrXAkEAuTxU7XnW8khKVqaszlerWE9ohhAgn6EMR4i3PcpYFF8rdz4AWQfn
gdfhAo9UARW0gjOMe9evnBup7RLONMxxHQJBAJS5QnluJYjc8pIQHU5a5ueG/Afl
Xnjii8Nc8y3wXw9pVSmALrVVyGGkX457TBd12kJ53zLLcfCaHA+Azx74IjkCQEKd
uOlCpROy/dEV1hXLH5r9y9hS2niuAW2EdGnraCvDYi1bBeL+3boregdiplJRjP46
La6oDca1iDHzTmdckt0CQFSu+N+zVpz582JcRO1VLSuQz9WDlivtlM8CJW4Xtoq1
ceKDIbnYCkGWKyflpgI77cxgRzv9ph0vE4r9LmqUwsE=
-----END RSA PRIVATE KEY-----
`,
    crypt_cert_sn: '68759622183',
    crypt_cert: `-----BEGIN CERTIFICATE-----
MIIEQzCCAyugAwIBAgIFEAJkkicwDQYJKoZIhvcNAQEFBQAwWDELMAkGA1UEBhMC
Q04xMDAuBgNVBAoTJ0NoaW5hIEZpbmFuY2lhbCBDZXJ0aWZpY2F0aW9uIEF1dGhv
cml0eTEXMBUGA1UEAxMOQ0ZDQSBURVNUIE9DQTEwHhcNMTUxMjE1MDkxMTM1WhcN
MTcxMjE1MDkxMTM1WjCBgTELMAkGA1UEBhMCY24xFzAVBgNVBAoTDkNGQ0EgVEVT
VCBPQ0ExMRIwEAYDVQQLEwlDRkNBIFRFU1QxFDASBgNVBAsTC0VudGVycHJpc2Vz
MS8wLQYDVQQDFCYwNDFAWjIwMTQtMTEtMTFAMDAwNDAwMDA6U0lHTkAwMDAwMDAw
NTCCASIwDQYJKoZIhvcNAQEBBQADggEPADCCAQoCggEBANHnoPx0JZKZmFjIURxN
AbLlWAw2jiFFWBnDF2MIGkya2r0fGiR0knq8zkKUnoIyC+tzEiOavniQaSu0ucuv
/V4ugz66PSRxw1gaPcR2dDVdgojF00TcewxlJEA65fK3eKhUYfC3NbRaVQOMMdwv
7nNEvzxvdExE47ceMya7FmsUPyLFu9X++chFQiYfr8nH+wdDeYo8w8vCX+Jd2vRu
qDOah29CQfkAmXsx3D68zg0q4AjlLI1t5gLKiU5YoG6yWrigPyreEHh716rV8HkT
jGWx3cxF/HsLZ/E4SgIr5yIZA6qw8RFqaSXuyw3iDrNf6aSJGO0GKlvxnvD20oGR
JokCAwEAAaOB6TCB5jAfBgNVHSMEGDAWgBTPcJ1h6518Lrj3ywJA9wmd/jN0gDBI
BgNVHSAEQTA/MD0GCGCBHIbvKgEBMDEwLwYIKwYBBQUHAgEWI2h0dHA6Ly93d3cu
Y2ZjYS5jb20uY24vdXMvdXMtMTQuaHRtMDgGA1UdHwQxMC8wLaAroCmGJ2h0dHA6
Ly91Y3JsLmNmY2EuY29tLmNuL1JTQS9jcmw0NTE3LmNybDALBgNVHQ8EBAMCA+gw
HQYDVR0OBBYEFGjriHHUE1MnYX7H6GrFi+8R2zmUMBMGA1UdJQQMMAoGCCsGAQUF
BwMCMA0GCSqGSIb3DQEBBQUAA4IBAQAjsN0fyDqcxS9YKMpY3CIdlarCjvnus+wS
ExjNnPv7n2urqhz2Jf3yJuhxVVPzdgKT51C2UiR+/i1OJPWFx0IUos/v8js/TM5j
mTdPkBsRSxSDieHHiuE1nPUwGXUEO7mlOVkkzmLI75bJ86foxNflbQCF0+VvpMe7
KwQoNOR8DxIBxHdlsjSxE2RKM/ftXLhptrK4GK3K4FAcSiqBMEn5PF/5V9mHp5N6
3LdkMYqBj4pRcy8vrclucq99b2glmMLw7CI6Kxu22WVoRnZESjcgXiMVLLe+qy55
0pWcZ2BChS7Ln19tj49LnS3vFp6xf4qNSqxEBaQuNLEx0ObjI6pz
-----END CERTIFICATE-----
`,
    verify_cer: `-----BEGIN CERTIFICATE-----
MIIEOjCCAyKgAwIBAgIFEAJkAUkwDQYJKoZIhvcNAQEFBQAwWDELMAkGA1UEBhMC
Q04xMDAuBgNVBAoTJ0NoaW5hIEZpbmFuY2lhbCBDZXJ0aWZpY2F0aW9uIEF1dGhv
cml0eTEXMBUGA1UEAxMOQ0ZDQSBURVNUIE9DQTEwHhcNMTUxMjA0MDMyNTIxWhcN
MTcxMjA0MDMyNTIxWjB5MQswCQYDVQQGEwJjbjEXMBUGA1UEChMOQ0ZDQSBURVNU
IE9DQTExEjAQBgNVBAsTCUNGQ0EgVEVTVDEUMBIGA1UECxMLRW50ZXJwcmlzZXMx
JzAlBgNVBAMUHjA0MUBaMTJAMDAwNDAwMDA6U0lHTkAwMDAwMDA2MjCCASIwDQYJ
KoZIhvcNAQEBBQADggEPADCCAQoCggEBAMUDYYCLYvv3c911zhRDrSWCedAYDJQe
fJUjZKI2avFtB2/bbSmKQd0NVvh+zXtehCYLxKOltO6DDTRHwH9xfhRY3CBMmcOv
d2xQQvMJcV9XwoqtCKqhzguoDxJfYeGuit7DpuRsDGI0+yKgc1RY28v1VtuXG845
fTP7PRtJrareQYlQXghMgHFAZ/vRdqlLpVoNma5C56cJk5bfr2ngDlXbUqPXLi1j
iXAFb/y4b8eGEIl1LmKp3aPMDPK7eshc7fLONEp1oQ5Jd1nE/GZj+lC345aNWmLs
l/09uAvo4Lu+pQsmGyfLbUGR51KbmHajF4Mrr6uSqiU21Ctr1uQGkccCAwEAAaOB
6TCB5jAfBgNVHSMEGDAWgBTPcJ1h6518Lrj3ywJA9wmd/jN0gDBIBgNVHSAEQTA/
MD0GCGCBHIbvKgEBMDEwLwYIKwYBBQUHAgEWI2h0dHA6Ly93d3cuY2ZjYS5jb20u
Y24vdXMvdXMtMTQuaHRtMDgGA1UdHwQxMC8wLaAroCmGJ2h0dHA6Ly91Y3JsLmNm
Y2EuY29tLmNuL1JTQS9jcmw0NDkxLmNybDALBgNVHQ8EBAMCA+gwHQYDVR0OBBYE
FAFmIOdt15XLqqz13uPbGQwtj4PAMBMGA1UdJQQMMAoGCCsGAQUFBwMCMA0GCSqG
SIb3DQEBBQUAA4IBAQB8YuMQWDH/Ze+e+2pr/914cBt94FQpYqZOmrBIQ8kq7vVm
TTy94q9UL0pMMHDuFJV6Wxng4Me/cfVvWmjgLg/t7bdz0n6UNj4StJP17pkg68WG
zMlcjuI7/baxtDrD+O8dKpHoHezqhx7dfh1QWq8jnqd3DFzfkhEpuIt6QEaUqoWn
t5FxSUiykTfjnaNEEGcn3/n2LpwrQ+upes12/B778MQETOsVv4WX8oE1Qsv1XLRW
i0DQetTU2RXTrynv+l4kMy0h9b/Hdlbuh2s0QZqlUMXx2biy0GvpF2pR8f+OaLuT
AtaKdU4T2+jO44+vWNNN2VoAaw0xY6IZ3/A1GL0x
-----END CERTIFICATE-----
`
}


describe('rna', () => {
    describe('#exchange()', () => {
        it('借记卡实名认证', async () => {
            await index.rna.exchange(
                'https://gateway.test.95516.com/gateway/api/backTransReq.do',
                Object.assign({
                    order_id: uuid.v4().replace(/-/g, ''),
                    acct_no: '6216261000000000018',
                    // acct_name: '全渠道',
                    acct_cert_no: '341126197709218366',
                }, info));
        });

        it('贷记卡实名认证', async () => {
            await index.rna.exchange(
                'https://gateway.test.95516.com/gateway/api/backTransReq.do',
                Object.assign({
                    order_id: uuid.v4().replace(/-/g, ''),
                    acct_no: '6221558812340000',
                    acct_name: '互联网',
                    // acct_cert_no: '341126197709218366',
                }, info));
        });
    });
});
